#!/usr/bin/env node
"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.init = void 0;
require("reflect-metadata");
const inversify_1 = require("inversify");
const cli_1 = require("./controllers/cli");
const types_1 = require("./types");
const template_engine_1 = require("./services/template-engine");
const file_output_stream_1 = require("./services/file-output-stream");
const free_comments_extractor_1 = require("./services/free-comments-extractor");
const tag_comments_parser_1 = require("./services/tag-comments-parser");
const microfocus_comments_extractor_1 = require("./services/microfocus-comments-extractor");
const xml_comments_parser_1 = require("./services/xml-comments-parser");
const documentation_service_1 = require("./services/documentation-service");
function init() {
    const container = new inversify_1.Container();
    container.bind(types_1.TYPES.FileOutputStream).to(file_output_stream_1.FileOutputStreamImpl).inSingletonScope();
    container.bind(types_1.TYPES.TemplateEngine).to(template_engine_1.TemplateEngineImpl).inSingletonScope();
    container.bind(types_1.TYPES.FreeCommentsExtractor).to(free_comments_extractor_1.FreeCommentsExtractorImpl).inSingletonScope();
    container.bind(types_1.TYPES.MicrofocusCommentsExtractor).to(microfocus_comments_extractor_1.MicrofocusCommentsExtractorImpl).inSingletonScope();
    container.bind(types_1.TYPES.TagCommentsParser).to(tag_comments_parser_1.TagCommentsParserImpl).inSingletonScope();
    container.bind(types_1.TYPES.XmlCommentsParser).to(xml_comments_parser_1.XmlCommentsParserImpl).inSingletonScope();
    container.bind(types_1.TYPES.DocumentationService).to(documentation_service_1.DocumentationServiceImpl).inSingletonScope();
    container.bind(types_1.TYPES.Cli).to(cli_1.Cli).inSingletonScope();
    return container.get(types_1.TYPES.Cli);
}
exports.init = init;
const app = init();
app.main(process.argv);
