"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.FreeCommentsExtractorImpl = void 0;
const tslib_1 = require("tslib");
const inversify_1 = require("inversify");
const fs = tslib_1.__importStar(require("fs"));
const path = tslib_1.__importStar(require("path"));
let FreeCommentsExtractorImpl = class FreeCommentsExtractorImpl {
    extract(filePath) {
        const data = fs.readFileSync(filePath, 'utf8');
        const lines = data.split(/\r?\n/);
        let comments = [];
        const fileComments = [];
        let isFileComments = false;
        let isComments = false;
        const functions = [];
        const modules = [];
        let lineCounter = 1;
        lines.forEach((line) => {
            if (/^\s*\*\>[^*].*/.test(line)) {
                if (isFileComments) {
                    fileComments.push(line);
                }
                if (isComments) {
                    comments.push(line);
                }
            }
            else if (/^\s*\*\>\*\*.*/.test(line)) {
                isFileComments = !isFileComments;
                isComments = false;
            }
            else if (/^\s*\*\>\*.*/.test(line)) {
                isComments = !isComments;
                isFileComments = false;
            }
            else if (/^\s*function-id\..+/i.test(line)) {
                functions.push({
                    name: line.split(".")[1].trim(),
                    line: lineCounter,
                    comments: this._cleanComments(comments),
                });
                comments = [];
            }
            else if (/^\s*program-id\..+/i.test(line)) {
                modules.push({
                    name: line.split(".")[1].trim(),
                    line: lineCounter,
                    comments: this._cleanComments(comments),
                });
                comments = [];
            }
            lineCounter++;
        });
        return {
            fileName: path.basename(filePath),
            fileComments: this._cleanComments(fileComments),
            functions: functions,
            modules: modules,
        };
    }
    _cleanComments(comments) {
        return comments
            .map(comment => comment.replace(/^\s*\*>\**\s*/, ''))
            .join('\n');
    }
};
FreeCommentsExtractorImpl = tslib_1.__decorate([
    inversify_1.injectable()
], FreeCommentsExtractorImpl);
exports.FreeCommentsExtractorImpl = FreeCommentsExtractorImpl;
