"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.TagCommentsParserImpl = void 0;
const tslib_1 = require("tslib");
const inversify_1 = require("inversify");
let TagCommentsParserImpl = class TagCommentsParserImpl {
    constructor() { }
    parse(preDocumentation) {
        const [fileDescription, author, license] = this._extractFileDetails(preDocumentation.fileComments);
        const modules = preDocumentation.modules.map(preModule => this._extractModuleOrFunction(preModule));
        const functions = preDocumentation.functions.map(preFunction => this._extractModuleOrFunction(preFunction));
        return {
            fileName: preDocumentation.fileName,
            fileDescription: fileDescription,
            author: author,
            license: license,
            functions: functions,
            modules: modules,
        };
    }
    _extractModuleOrFunction(preModuleOrFunction) {
        const pieces = preModuleOrFunction.comments.split('@');
        const params = [];
        let returnObj = undefined;
        let description = undefined;
        let summary = undefined;
        pieces.forEach((piece, index) => {
            if (index === 0) {
                description = piece;
                summary = piece;
            }
            else if (/^summary/.test(piece)) {
                summary = piece.substring(piece.indexOf(' ') + 1);
            }
            else if (/^param/.test(piece)) {
                piece = piece.substring(piece.indexOf(' ') + 1);
                let paramType = undefined;
                const match = piece.match(/\{(.+)\}/);
                if (!!match) {
                    paramType = match[1];
                    piece = piece.replace(/\{(.+)\}/, '').trim();
                }
                const paramName = piece.substring(0, piece.indexOf(' '));
                const paramDescription = piece.substring(piece.indexOf(' ') + 1).trim();
                params.push({
                    name: paramName,
                    description: paramDescription,
                    type: paramType,
                });
            }
            else if (/^return/.test(piece)) {
                let returnType = undefined;
                const match = piece.match(/\{(.+)\}/);
                if (!!match) {
                    returnType = match[1];
                    piece = piece.replace(/\{(.+)\}/, '').trim();
                }
                const returnDescription = piece.substring(piece.indexOf(' ') + 1).trim();
                returnObj = {
                    description: returnDescription,
                    type: returnType,
                };
            }
        });
        return {
            description: description,
            line: preModuleOrFunction.line,
            name: preModuleOrFunction.name,
            paragraphs: [],
            params: params,
            return: returnObj,
            summary: summary,
        };
    }
    _extractFileDetails(comments) {
        const pieces = comments.split('@');
        let author = undefined;
        let license = undefined;
        let description = undefined;
        pieces.forEach((piece, index) => {
            if (index === 0) {
                description = piece.trim();
            }
            else if (/^license/.test(piece)) {
                license = piece.substring(piece.indexOf(' ') + 1);
            }
            else if (/^author/.test(piece)) {
                author = piece.substring(piece.indexOf(' ') + 1);
            }
        });
        return [description, author, license];
    }
};
TagCommentsParserImpl = tslib_1.__decorate([
    inversify_1.injectable(),
    tslib_1.__metadata("design:paramtypes", [])
], TagCommentsParserImpl);
exports.TagCommentsParserImpl = TagCommentsParserImpl;
