"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.TemplateEngineImpl = void 0;
const tslib_1 = require("tslib");
const inversify_1 = require("inversify");
const ejs = tslib_1.__importStar(require("ejs"));
const fs = tslib_1.__importStar(require("fs"));
const path = tslib_1.__importStar(require("path"));
const format_1 = require("../model/format");
let TemplateEngineImpl = class TemplateEngineImpl {
    constructor() {
        this._templateFunctions = new Map();
        Object.values(format_1.Format).forEach(format => {
            const templatePath = path.join(__dirname, `../resources/templates/${format}.ejs`);
            const template = fs.readFileSync(templatePath, 'utf8');
            this._templateFunctions.set(format, ejs.compile(template));
            const tableOfContentsTemplatePath = path.join(__dirname, `../resources/templates/table-of-contents.${format}.ejs`);
            const templtableOfContentsTemplate = fs.readFileSync(tableOfContentsTemplatePath, 'utf8');
            this._templateFunctions.set(`table-of-contents.${format}`, ejs.compile(templtableOfContentsTemplate));
        });
    }
    parseDocumentation(format, documentation) {
        const renderFunction = this._templateFunctions.get(format);
        if (!renderFunction) {
            throw new Error(`template not found: ${format}`);
        }
        return renderFunction(documentation);
    }
    parseTableOfContents(format, fileNames) {
        const renderFunction = this._templateFunctions.get(`table-of-contents.${format}`);
        if (!renderFunction) {
            throw new Error(`template of table of contents not found: ${format}`);
        }
        return renderFunction({ fileNames });
    }
};
TemplateEngineImpl = tslib_1.__decorate([
    inversify_1.injectable(),
    tslib_1.__metadata("design:paramtypes", [])
], TemplateEngineImpl);
exports.TemplateEngineImpl = TemplateEngineImpl;
